@@ -1,5 +1,7 @@
 def superusers_only(*, hijacker, hijacked):
     """Superusers may hijack any other user."""
+    if not hijacked:
+        return False
     return hijacked.is_active and hijacker.is_superuser
 
 
@@ -10,7 +12,7 @@ def superusers_and_staff(*, hijacker, hijacked):
     A superuser may hijack any other user.
     A staff member may hijack any user, except another staff member or superuser.
     """
-    if not hijacked.is_active:
+    if not hijacked or not hijacked.is_active:
         return False
 
     if hijacker.is_superuser:
